GridArea

Struct GridArea 

pub struct GridArea {
    pub row_start: usize,
    pub row_end: usize,
    pub col_start: usize,
    pub col_end: usize,
}
A named grid area spanning rows and columns.

Fields

row_start: usize

Starting row (0-indexed)

row_end: usize

Ending row (exclusive)

col_start: usize

Starting column (0-indexed)

col_end: usize

Ending column (exclusive)

Implementations

Source

impl GridArea

pub const fn new( row_start: usize, col_start: usize, row_end: usize, col_end: usize, ) -> Self

Create a new grid area.

pub const fn cell(row: usize, col: usize) -> Self

Create a single-cell area.

pub const fn row_span(row: usize, col_start: usize, col_end: usize) -> Self

Create an area spanning multiple columns in a single row.

pub const fn col_span(col: usize, row_start: usize, row_end: usize) -> Self

Create an area spanning multiple rows in a single column.

pub const fn row_span_count(&self) -> usize

Get the number of rows this area spans.

pub const fn col_span_count(&self) -> usize

Get the number of columns this area spans.