pub struct GridArea {
pub row_start: usize,
pub row_end: usize,
pub col_start: usize,
pub col_end: usize,
}Expand description
A named grid area spanning rows and columns.
Fields
row_start: usizeStarting row (0-indexed)
row_end: usizeEnding row (exclusive)
col_start: usizeStarting column (0-indexed)
col_end: usizeEnding column (exclusive)
Implementations
Sourceimpl GridArea
impl GridArea
Sourcepub const fn new(
row_start: usize,
col_start: usize,
row_end: usize,
col_end: usize,
) -> Self
pub const fn new( row_start: usize, col_start: usize, row_end: usize, col_end: usize, ) -> Self
Create a new grid area.
Sourcepub const fn row_span(row: usize, col_start: usize, col_end: usize) -> Self
pub const fn row_span(row: usize, col_start: usize, col_end: usize) -> Self
Create an area spanning multiple columns in a single row.
Sourcepub const fn col_span(col: usize, row_start: usize, row_end: usize) -> Self
pub const fn col_span(col: usize, row_start: usize, row_end: usize) -> Self
Create an area spanning multiple rows in a single column.
Sourcepub const fn row_span_count(&self) -> usize
pub const fn row_span_count(&self) -> usize
Get the number of rows this area spans.
Sourcepub const fn col_span_count(&self) -> usize
pub const fn col_span_count(&self) -> usize
Get the number of columns this area spans.